<?php

namespace App\Http\Controllers\Admin;

use App\Models\BankAccount;
use App\Models\Pix;
use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;
class AccountController extends Controller
{
    // Mostrar o formulário de cadastro de conta e Pix
    public function showAccountForm()
    {
        return view('admin.accounts');
    }

    // Salvar dados da conta bancária
    public function saveBankAccount(Request $request)
    {
        $request->validate([
            'account_holder' => 'required',
            'bank_name' => 'required',
            'account_number' => 'required',
            'agency_number' => 'required',
            'bank_code' => 'required',
        ]);

        BankAccount::create([
            'account_holder' => $request->account_holder,
            'bank_name' => $request->bank_name,
            'account_number' => $request->account_number,
            'agency_number' => $request->agency_number,
            'bank_code' => $request->bank_code,
        ]);

        return redirect()->back()->with('success', 'Conta bancária cadastrada com sucesso!');
    }

    // Salvar dados do Pix
    public function savePix(Request $request)
    {
        $request->validate([
            'pix_key' => 'required',
            'pix_type' => 'required',
        ]);

        Pix::create([
            'pix_key' => $request->pix_key,
            'pix_type' => $request->pix_type,
        ]);

        return redirect()->back()->with('success', 'Chave Pix cadastrada com sucesso!');
    }
    public function index()
    {
        $users = User::all(); // Recupera todos os usuários
        return view('admin.accounts.index', compact('users'));
    }

    // Mostrar o formulário para editar um usuário
    public function edit($id)
    {
        $user = User::findOrFail($id);
        return view('admin.accounts.edit', compact('user'));
    }

    // Atualizar dados do usuário
    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:users,email,' . $id,
            'is_admin' => 'required|boolean',
        ]);

        $user = User::findOrFail($id);
        $user->update($request->all());

        return redirect()->route('admin.accounts.index')->with('success', 'Conta atualizada com sucesso!');
    }

    // Excluir um usuário
    public function destroy($id)
    {
        $user = User::findOrFail($id);
        $user->delete();

        return redirect()->route('admin.accounts.index')->with('success', 'Conta excluída com sucesso!');
    }
}