<?php
namespace App\Http\Controllers;

use App\Models\MeioContato;
use Illuminate\Http\Request;

class AdminMeiosContatoController extends Controller
{
    // Exibe a lista de meios de contato
    public function index()
    {
        $meiosContato = MeioContato::orderBy('ordem')->get();
        return view('admin.meios_contato.index', compact('meiosContato'));
    }

    // Exibe o formulário de criação
    public function create()
    {
        return view('admin.meios_contato.create');
    }

    // Salva o novo meio de contato
    public function store(Request $request)
    {
        $request->validate([
            'tipo' => 'required|string|max:50',
            'descricao' => 'required|string|max:255',
            'icone' => 'nullable|string|max:50',
            'ordem' => 'nullable|integer',
        ]);

        MeioContato::create($request->all());
        return redirect()->route('admin.meios_contato.index')->with('success', 'Meio de contato criado com sucesso.');
    }

    // Exibe o formulário de edição
    public function edit($id)
    {
        $meioContato = MeioContato::findOrFail($id);
        return view('admin.meios_contato.edit', compact('meioContato'));
    }

    // Atualiza o meio de contato
    public function update(Request $request, $id)
    {
        $request->validate([
            'tipo' => 'required|string|max:50',
            'descricao' => 'required|string|max:255',
            'icone' => 'nullable|string|max:50',
            'ordem' => 'nullable|integer',
        ]);

        $meioContato = MeioContato::findOrFail($id);
        $meioContato->update($request->all());
        return redirect()->route('admin.meios_contato.index')->with('success', 'Meio de contato atualizado com sucesso.');
    }

    // Exclui um meio de contato
    public function destroy($id)
    {
        $meioContato = MeioContato::findOrFail($id);
        $meioContato->delete();
        return redirect()->route('admin.meios_contato.index')->with('success', 'Meio de contato excluído com sucesso.');
    }
}