<?php

namespace App\Http\Controllers;

use App\Models\Cliente;
use Illuminate\Http\Request;

class ClienteController extends Controller
{
    public function index()
    {
        $clientes = Cliente::all();
        return view('clientes.index', compact('clientes'));
    }

    public function create()
    {
        $clientes = Cliente::all();
    return view('clientes.create', compact('clientes'));
    }

    public function store(Request $request)
    {
        $validated = $request->validate([
            'nome_cliente' => 'required|string|max:255',
            'endereco_cliente' => 'required|string|max:255',
            'telefone_contato' => 'required|string|max:20',
            'indicacoes' => 'nullable|array',
            'numero_pedidos' => 'nullable|integer',
        ]);

        // Filtrar IDs válidos e remover o valor "0"
        $indicacoesNovas = array_filter($request->indicacoes, fn($id) => $id != 0);

        // Se houver ID de cliente existente
        $clienteExistente = Cliente::find($request->id);
        if ($clienteExistente && $clienteExistente->indicacoes) {
            $indicacoesAntigas = json_decode($clienteExistente->indicacoes, true) ?? [];
        } else {
            $indicacoesAntigas = [];
        }

        // Combinar as novas e antigas indicações
        $indicacoes = array_unique(array_merge($indicacoesAntigas, $indicacoesNovas));

        $validated['indicacoes'] = json_encode($indicacoes);

        Cliente::create($validated);

        return redirect()->route('clientes.index')->with('success', 'Cliente cadastrado com sucesso!');
    }



    public function edit(Cliente $cliente)
    {
        // Decodificar o campo indicacoes para garantir que seja um array
        $indicacoesIds = json_decode($cliente->indicacoes ?? '[]', true);

        // Buscar os nomes dos clientes indicados
        $indicados = Cliente::whereIn('id', $indicacoesIds)->pluck('nome_cliente')->toArray();

        // Obter todos os clientes disponíveis para seleção
        $todosClientes = Cliente::all();

        return view('clientes.edit', compact('cliente', 'indicados', 'todosClientes'));
    }


    public function update(Request $request, Cliente $cliente)
    {
        $validated = $request->validate([
            'nome_cliente' => 'required|string|max:255',
            'endereco_cliente' => 'required|string|max:255',
            'telefone_contato' => 'required|string|max:20',
            'indicacoes' => 'nullable|array',
            'numero_pedidos' => 'nullable|integer',
        ]);

        $validated['indicacoes'] = json_encode($request->indicacoes);

        $cliente->update($validated);

        return redirect()->route('clientes.index')->with('success', 'Cliente atualizado com sucesso!');
    }
}