<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Produto;

class ProdutoController extends Controller
{
    /**
     * Exibe o formulário de cadastro de produtos.
     */
    public function create()
    {
        return view('produtos.create');
    }

    /**
     * Salva um novo produto no banco de dados e realiza o upload da imagem.
     */
    public function store(Request $request)
    {
        // Validação dos dados
        $request->validate([
            'nome' => 'required|string|max:255',
            'valor' => 'required|numeric',
            'peso' => 'required|numeric',
            'tipo' => 'required|string|in:pct,quilo,unidade,litros',
            'estoque' => 'required|integer',
            'imagem' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        // Instancia um novo produto
        $produto = new Produto();
        $produto->nome = $request->input('nome');
        $produto->valor = $request->input('valor');
        $produto->peso = $request->input('peso');
        $produto->tipo = $request->input('tipo');
        $produto->estoque = $request->input('estoque');

        // Upload da imagem, se fornecida
        if ($request->hasFile('imagem')) {
            $imagem = $request->file('imagem');
            $nomeArquivo = time() . '_' . $imagem->getClientOriginalName();
            $caminho = $imagem->storeAs('img/produtos', $nomeArquivo, 'public');
            $produto->imagem = $caminho; // Salva o caminho no banco
        }

        // Salva o produto no banco
        $produto->save();

        // Redireciona para a página de sucesso ou lista de produtos
        return redirect()->route('produtos.index')->with('success', 'Produto cadastrado com sucesso!');
    }
    public function index()
    {
        // Recupera todos os produtos do banco de dados
        $produtos = Produto::all();

        // Retorna a view e passa os produtos para ela
        return view('produtos.index', compact('produtos'));
    }
     // Método para exibir o formulário de edição
     public function edit($id)
     {
         $produto = Produto::findOrFail($id); // Encontra o produto com o ID fornecido
         return view('produtos.edit', compact('produto')); // Passa o produto para a view de edição
     }

     // Método para atualizar um produto existente
     public function update(Request $request, $id)
     {
         $produto = Produto::findOrFail($id); // Encontra o produto com o ID fornecido
         $produto->update($request->all()); // Atualiza os dados do produto

         return redirect()->route('produtos.index');
     }

     // Método para exibir os detalhes de um produto
     public function show($id)
     {
         $produto = Produto::findOrFail($id); // Encontra o produto com o ID fornecido
         return view('produtos.show', compact('produto')); // Passa o produto para a view de detalhes
     }

     // Método para excluir um produto
     public function destroy($id)
     {
         Produto::destroy($id); // Exclui o produto com o ID fornecido
         return redirect()->route('produtos.index');
     }
}