@extends('layouts.main')

@section('content')
    <div class="container">
        <h1>Editar Usuário</h1>

        @if ($errors->any())
            <div class="alert alert-danger">
                <ul>
                    @foreach ($errors->all() as $error)
                        <li>{{ $error }}</li>
                    @endforeach
                </ul>
            </div>
        @endif

        <div class="container-edit-user">
            <form action="{{ route('users.update', $user->id) }}" method="POST" enctype="multipart/form-data">
                @csrf
                @method('PUT')

                <div class="aling-itens">
                    <!-- Nome -->

                    @if ($user->photo)
                        <img class="foto-perfil-edit" src="{{ asset('storage/' . $user->photo) }}" alt="Foto do usuário"
                            style="max-width: 150px; margin-top: 10px;">
                    @endif
                    <div class="aling-itens-col">
                        <div class="form-group">
                            <label for="name">Nome</label>
                            <input type="text" class="form-control" id="name" name="name"
                                value="{{ old('name', $user->name) }}" required>
                        </div>

                        <!-- Email -->
                        <div class="form-group">
                            <label for="email">Email</label>
                            <input type="email" class="form-control" id="email" name="email"
                                value="{{ old('email', $user->email) }}" required>
                        </div>
                    </div>
                    <!-- Telefone -->
                    <div class="aling-itens-col">
                        <div class="form-group">
                            <label for="phone">Telefone</label>
                            <input type="text" class="form-control phone-mask" id="phone" name="phone"
                                value="{{ old('phone', $user->phone) }}">
                        </div>
                        @if (auth()->user()->is_admin)
                            <div class="form-group">
                                <label for="role">Função no sistema</label>
                                <select class="form-control" id="role" name="role">
                                    <option value="user" {{ $user->role === 'user' ? 'selected' : '' }}>Usuário</option>
                                    <option value="admin" {{ $user->role === 'admin' ? 'selected' : '' }}>Administrador
                                    </option>
                                </select>
                            </div>
                        @endif
                    </div>

                    <div class="form-group">
                        <label for="password">Nova Senha</label>
                        <input type="password" class="form-control" id="password" name="password">
                        <small>Deixe em branco para manter a senha atual.</small>
                    </div>

                    <!-- Confirmação de Senha -->
                    <div class="form-group">
                        <label for="password_confirmation">Confirmação da Nova Senha</label>
                        <input type="password" class="form-control" id="password_confirmation" name="password_confirmation">
                    </div>

                </div>





                <!-- Endereço -->
                <h4>Endereço</h4>
                <div class="aling-itens">
                    <div class="form-group">
                        <label for="cep">CEP</label>
                        <input type="text" class="form-control" id="cep" name="cep"
                            value="{{ old('cep', $user->cep) }}">
                    </div>
                    <div class="form-group">
                        <label for="neighborhood">Bairro</label>
                        <input type="text" class="form-control" id="neighborhood" name="neighborhood"
                            value="{{ old('neighborhood', $user->neighborhood) }}">
                    </div>
                    <div class="form-group">
                        <label for="street">Rua</label>
                        <input type="text" class="form-control" id="street" name="street"
                            value="{{ old('street', $user->street) }}">
                    </div>
                </div>
                <div class="aling-itens">
                    <div class="form-group">
                        <label for="city">Cidade</label>
                        <input type="text" class="form-control" id="city" name="city"
                            value="{{ old('city', $user->city) }}">
                    </div>
                    <div class="form-group">
                        <label for="number">Número</label>
                        <input type="text" class="form-control" id="number" name="number"
                            value="{{ old('number', $user->number) }}">
                    </div>
                    <div class="form-group">
                        <label for="state">Estado</label>
                        <input type="text" class="form-control" id="state" name="state"
                            value="{{ old('state', $user->state) }}">
                    </div>
                </div>

                <!-- Foto -->
                <div class="form-group">
                    <label for="photo">Foto</label>
                    <input type="file" class="form-control" id="photo" name="photo" accept="image/*">

                </div>

                <!-- Botões -->
                <button type="submit" class="btn btn-primary">Salvar</button>
                <a href="{{ route('accounts.index') }}" class="btn btn-secondary">Cancelar</a>
            </form>
        </div>
    </div>

    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery.mask/1.14.16/jquery.mask.min.js"></script>

    <script>
        $(document).ready(function() {
            // Máscara de telefone
            $('.phone-mask').mask('(00) 00000-0000');

            // Busca de CEP
            $('#cep').on('blur', function() {
                let cep = $(this).val().replace(/\D/g, '');
                if (cep.length === 8) {
                    $.getJSON(`https://viacep.com.br/ws/${cep}/json/`, function(data) {
                        if (!("erro" in data)) {
                            $('#street').val(data.logradouro);
                            $('#neighborhood').val(data.bairro);
                            $('#city').val(data.localidade);
                            $('#state').val(data.uf);
                        } else {
                            alert('CEP não encontrado.');
                        }
                    }).fail(function() {
                        alert('Erro ao buscar o CEP. Tente novamente.');
                    });
                }
            });
        });
    </script>
@endsection
